ftd2xx-sys 0.2.0

libftd2xx FFI bindings
docs.rs failed to build ftd2xx-sys-0.2.0
Please check the build logs for more information.
See Builds for ideas on how to fix a failed build, or Metadata for how to configure docs.rs builds.
If you believe this is docs.rs' fault, open an issue.

FTD2XX-SYS

This crate generates Rust FFI (Foreign Function Interface) bindings for the FTDI D2XX library and the FTDI MPSSE I2C & SPI libraries using bindgen.

For its usage, the libftd2xx (and optionally libmpsse) must be installed in one of the following paths:

  • /usr/lib and /usr/include.
  • /usr/local/lib and /usr/local/include
  • Any path set in the LD_LIBRARY_PATH env. variable.

The LD_LIBRARY_PATH variable takes precedence over the system paths.

To install the libraries into /usr/local/lib, a helper script install_libs.sh is provided.

./install_d2xx.sh <path_to_libftd2xx.so> [path_to_libmpsse.so]

You may choose to compile the library statically or dynamically by setting the static feature in your Cargo.toml. By default, the library is dynamically linked. Also, you can optionally generate the bindings for the libmpsse, provided that it is installed in your system. By default, bindings for this library won't be generated.

[dependencies]
ftd2xx-sys = { version = "x.x.x", features = ["static", "mpsse"] }